<?php

/**
 * This is the model class for table "app_store_transaction".
 *
 * The followings are the available columns in table 'app_store_transaction':
 * @property integer $id
 * @property integer $user_id
 * @property string $product_identifier
 * @property integer $quantitiy
 * @property string $transaction_date_time
 * @property string $transaction_identifier
 * @property string $transaction_receipt
 * @property integer $receipt_verification_status_code
 */
class AppStoreTransaction extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'app_store_transaction';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('user_id, product_identifier, quantitiy, transaction_date_time, transaction_identifier, transaction_receipt', 'required'),
			array('user_id, quantitiy, receipt_verification_status_code', 'numerical', 'integerOnly'=>true),
			array('product_identifier', 'length', 'max'=>1000),
			array('transaction_identifier', 'length', 'max'=>100),
			array('transaction_receipt', 'length', 'max'=>4096),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, user_id, product_identifier, quantitiy, transaction_date_time, transaction_identifier, transaction_receipt, receipt_verification_status_code', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'user_id' => 'User',
			'product_identifier' => 'Product Identifier',
			'quantitiy' => 'Quantitiy',
			'transaction_date_time' => 'Transaction Date Time',
			'transaction_identifier' => 'Transaction Identifier',
			'transaction_receipt' => 'Transaction Receipt',
			'receipt_verification_status_code' => 'Receipt Verification Status Code',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('product_identifier',$this->product_identifier,true);
		$criteria->compare('quantitiy',$this->quantitiy);
		$criteria->compare('transaction_date_time',$this->transaction_date_time,true);
		$criteria->compare('transaction_identifier',$this->transaction_identifier,true);
		$criteria->compare('transaction_receipt',$this->transaction_receipt,true);
		$criteria->compare('receipt_verification_status_code',$this->receipt_verification_status_code);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return AppStoreTransaction the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
