<?php

/**
 * This is the model class for table "contest_log".
 *
 * The followings are the available columns in table 'contest_log':
 * @property integer $id
 * @property integer $user_id
 * @property integer $category_id
 * @property integer $award_id
 * @property string $remaining_joker_ids_str
 * @property string $remaining_question_ids_str
 * @property integer $asked_question_id
 * @property string $answered_question_ids_str
 * @property string $start_date_time
 * @property string $end_date_time
 * @property integer $result_point
 * @property integer $is_test
 * @property string $token
 */
class ContestLog extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'contest_log';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('user_id, start_date_time, result_point, is_test, token', 'required'),
			array('user_id, category_id, award_id, asked_question_id, result_point, is_test', 'numerical', 'integerOnly'=>true),
			array('remaining_joker_ids_str', 'length', 'max'=>100),
			array('remaining_question_ids_str, answered_question_ids_str', 'length', 'max'=>500),
			array('token', 'length', 'max'=>40),
			array('end_date_time', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, user_id, category_id, award_id, remaining_joker_ids_str, remaining_question_ids_str, asked_question_id, answered_question_ids_str, start_date_time, end_date_time, result_point, is_test, token', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'user_id' => 'User',
			'category_id' => 'Category',
			'award_id' => 'Award',
			'remaining_joker_ids_str' => 'Remaining Joker Ids Str',
			'remaining_question_ids_str' => 'Remaining Question Ids Str',
			'asked_question_id' => 'Asked Question',
			'answered_question_ids_str' => 'Answered Question Ids Str',
			'start_date_time' => 'Start Date Time',
			'end_date_time' => 'End Date Time',
			'result_point' => 'Result Point',
			'is_test' => 'Is Test',
			'token' => 'Token',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('category_id',$this->category_id);
		$criteria->compare('award_id',$this->award_id);
		$criteria->compare('remaining_joker_ids_str',$this->remaining_joker_ids_str,true);
		$criteria->compare('remaining_question_ids_str',$this->remaining_question_ids_str,true);
		$criteria->compare('asked_question_id',$this->asked_question_id);
		$criteria->compare('answered_question_ids_str',$this->answered_question_ids_str,true);
		$criteria->compare('start_date_time',$this->start_date_time,true);
		$criteria->compare('end_date_time',$this->end_date_time,true);
		$criteria->compare('result_point',$this->result_point);
		$criteria->compare('is_test',$this->is_test);
		$criteria->compare('token',$this->token,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return ContestLog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
