<?php

/**
 * This is the model class for table "trial_log".
 *
 * The followings are the available columns in table 'trial_log':
 * @property integer $id
 * @property integer $user_id
 * @property integer $contest_id
 * @property integer $question_id
 * @property integer $selected_option_id
 * @property string $display_question_date_time
 * @property string $answer_question_date_time
 */
class TrialLog extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'trial_log';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('user_id, contest_id, question_id, selected_option_id, display_question_date_time, answer_question_date_time', 'required'),
			array('user_id, contest_id, question_id, selected_option_id', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, user_id, contest_id, question_id, selected_option_id, display_question_date_time, answer_question_date_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'user_id' => 'User',
			'contest_id' => 'Contest',
			'question_id' => 'Question',
			'selected_option_id' => 'Selected Option',
			'display_question_date_time' => 'Display Question Date Time',
			'answer_question_date_time' => 'Answer Question Date Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('contest_id',$this->contest_id);
		$criteria->compare('question_id',$this->question_id);
		$criteria->compare('selected_option_id',$this->selected_option_id);
		$criteria->compare('display_question_date_time',$this->display_question_date_time,true);
		$criteria->compare('answer_question_date_time',$this->answer_question_date_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return TrialLog the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
